
1.2.0 (2018-07-14)
###################

Changes since 1.1.3 (2018-07-01).


Special Attention
$$$$$$$$$$$$$$$$$$

This release contains a significant improvement in the accuracy of
projecting variants in the vicinity of genome-transcript alignment
gaps. Previously, hgvs handled only a limited number of cases.  The
new AlignmentMapper now handles all cases identified for projecting
substitution, insertion, and deletion variants in the context of
substituion, insertion, and deletion alignment discrepancies. [Credit:
Meng Wang]


Deprecations and Removals
$$$$$$$$$$$$$$$$$$$$$$$$$$

AlignmentMapper replaces IntervalMapper and TranscriptMapper. The
latter are now deprecated and will be removed in the next release.


Bug Fixes
$$$$$$$$$$

* Fixes `#497 <https://github.com/biocommons/hgvs/issues/497/>`_: Honor normalize switch in AssemblyMapper [`61d363e <https://github.com/biocommons/hgvs/commit/61d363e>`_]


New Features
$$$$$$$$$$$$$

* Closes `#208 <https://github.com/biocommons/hgvs/issues/208/>`_: Rewrite coordination mapping to provide better support for projecting variants in the vicinity of transcript-alignment gaps.

